pub struct CustomDns {
pub ds_records: Option<Vec<DsRecord>>,
pub name_servers: Option<Vec<String>>,
}Expand description
Configuration for an arbitrary DNS provider.
This type is not used in any activity, and only used as part of another schema.
Fields
ds_records: Option<Vec<DsRecord>>The list of DS records for this domain, which are used to enable DNSSEC. The domain’s DNS provider can provide the values to set here. If this field is empty, DNSSEC is disabled.
name_servers: Option<Vec<String>>Required. A list of name servers that store the DNS zone for this domain. Each name server is a domain name, with Unicode domain names expressed in Punycode format.