pub struct Domain {
pub domain_name: Option<String>,
pub resource_state: Option<String>,
pub yearly_price: Option<Money>,
}Expand description
A domain that the calling user manages in Google Domains.
This type is not used in any activity, and only used as part of another schema.
Fields
domain_name: Option<String>The domain name. Unicode domain names are expressed in Punycode format.
resource_state: Option<String>The state of this domain as a Registration resource.
yearly_price: Option<Money>Price to renew the domain for one year. Only set when resource_state is IMPORTABLE.