pub struct DomainForwarding {
pub path_forwarding: Option<bool>,
pub pem_certificate: Option<String>,
pub redirect_type: Option<String>,
pub ssl_enabled: Option<bool>,
pub subdomain: Option<String>,
pub target_uri: Option<String>,
}Expand description
Domain forwarding configuration.
This type is not used in any activity, and only used as part of another schema.
Fields
path_forwarding: Option<bool>If true, forwards the path after the domain name to the same path at the new address.
pem_certificate: Option<String>The PEM-encoded certificate chain.
redirect_type: Option<String>The redirect type.
ssl_enabled: Option<bool>If true, the forwarding works also over HTTPS.
subdomain: Option<String>The subdomain of the registered domain that is being forwarded. E.g. www.example.com, example.com (i.e. the registered domain itself) or *.example.com (i.e. all subdomains).
target_uri: Option<String>The target of the domain forwarding, i.e. the path to redirect the subdomain to.