pub struct EmailForwarding {
pub alias: Option<String>,
pub target_email_address: Option<String>,
}Expand description
Email forwarding configuration.
This type is not used in any activity, and only used as part of another schema.
Fields
alias: Option<String>An alias recipient email that forwards emails to the target_email_address. For example, admin@example.com or *@example.com (wildcard alias forwards all the emails under the registered domain).
target_email_address: Option<String>Target email that receives emails sent to the alias.