pub struct GeoPolicy {
pub enable_fencing: Option<bool>,
pub item: Option<Vec<GeoPolicyItem>>,
}Expand description
Configures a RRSetRoutingPolicy that routes based on the geo location of the querying user.
This type is not used in any activity, and only used as part of another schema.
Fields
enable_fencing: Option<bool>Without fencing, if health check fails for all configured items in the current geo bucket, we failover to the next nearest geo bucket. With fencing, if health checking is enabled, as long as some targets in the current geo bucket are healthy, we return only the healthy targets. However, if all targets are unhealthy, we don’t failover to the next nearest bucket; instead, we return all the items in the current bucket even when all targets are unhealthy.
item: Option<Vec<GeoPolicyItem>>The primary geo routing configuration. If there are multiple items with the same location, an error is returned instead.