pub struct HealthCheckTargets {
pub external_endpoints: Option<Vec<String>>,
pub internal_load_balancer: Option<Vec<LoadBalancerTarget>>,
}Expand description
HealthCheckTargets describes endpoints to health-check when responding to Routing Policy queries. Only the healthy endpoints will be included in the response. Set either internal_load_balancer or external_endpoints. Do not set both.
This type is not used in any activity, and only used as part of another schema.
Fields
external_endpoints: Option<Vec<String>>The Internet IP addresses to be health checked. The format matches the format of ResourceRecordSet.rrdata as defined in RFC 1035 (section 5) and RFC 1034 (section 3.6.1)
internal_load_balancer: Option<Vec<LoadBalancerTarget>>Configuration for internal load balancers to be health checked.