ManagementSettings

Struct ManagementSettings 

pub struct ManagementSettings {
    pub effective_transfer_lock_state: Option<String>,
    pub preferred_renewal_method: Option<String>,
    pub renewal_method: Option<String>,
    pub transfer_lock_state: Option<String>,
}
Defines renewal, billing, and transfer settings for a Registration.

This type is not used in any activity, and only used as part of another schema.

Fields

effective_transfer_lock_state: Option<String>

Output only. The actual transfer lock state for this Registration.

preferred_renewal_method: Option<String>

Optional. The desired renewal method for this Registration. The actual renewal_method is automatically updated to reflect this choice. If unset or equal to RENEWAL_METHOD_UNSPECIFIED, the actual renewalMethod is treated as if it were set to AUTOMATIC_RENEWAL. You cannot use RENEWAL_DISABLED during resource creation, and you can update the renewal status only when the Registration resource has state ACTIVE or SUSPENDED. When preferred_renewal_method is set to AUTOMATIC_RENEWAL, the actual renewal_method can be set to RENEWAL_DISABLED in case of problems with the billing account or reported domain abuse. In such cases, check the issues field on the Registration. After the problem is resolved, the renewal_method is automatically updated to preferred_renewal_method in a few hours.

renewal_method: Option<String>

Output only. The actual renewal method for this Registration. When preferred_renewal_method is set to AUTOMATIC_RENEWAL, the actual renewal_method can be equal to RENEWAL_DISABLED—for example, when there are problems with the billing account or reported domain abuse. In such cases, check the issues field on the Registration. After the problem is resolved, the renewal_method is automatically updated to preferred_renewal_method in a few hours.

transfer_lock_state: Option<String>

This is the desired transfer lock state for this Registration. A transfer lock controls whether the domain can be transferred to another registrar. The transfer lock state of the domain is returned in the effective_transfer_lock_state property. The transfer lock state values might be different for the following reasons: * transfer_lock_state was updated only a short time ago. * Domains with the TRANSFER_LOCK_UNSUPPORTED_BY_REGISTRY state are in the list of domain_properties. These domains are always in the UNLOCKED state.