pub struct PrimaryBackupPolicy {
pub backup_geo_targets: Option<GeoPolicy>,
pub primary_targets: Option<HealthCheckTargets>,
pub trickle_traffic: Option<f64>,
}Expand description
Configures a RRSetRoutingPolicy such that all queries are responded with the primary_targets if they are healthy. And if all of them are unhealthy, then we fallback to a geo localized policy.
This type is not used in any activity, and only used as part of another schema.
Fields
backup_geo_targets: Option<GeoPolicy>Backup targets provide a regional failover policy for the otherwise global primary targets. If serving state is set to BACKUP, this policy essentially becomes a geo routing policy.
primary_targets: Option<HealthCheckTargets>Endpoints that are health checked before making the routing decision. Unhealthy endpoints are omitted from the results. If all endpoints are unhealthy, we serve a response based on the backup_geo_targets.
trickle_traffic: Option<f64>When serving state is PRIMARY, this field provides the option of sending a small percentage of the traffic to the backup targets.