pub struct RegisterParameters {
pub availability: Option<String>,
pub domain_name: Option<String>,
pub domain_notices: Option<Vec<String>>,
pub supported_privacy: Option<Vec<String>>,
pub yearly_price: Option<Money>,
}Expand description
Parameters required to register a new domain.
This type is not used in any activity, and only used as part of another schema.
Fields
availability: Option<String>Indicates whether the domain is available for registration. This value is accurate when obtained by calling RetrieveRegisterParameters, but is approximate when obtained by calling SearchDomains.
domain_name: Option<String>The domain name. Unicode domain names are expressed in Punycode format.
domain_notices: Option<Vec<String>>Notices about special properties of the domain.
supported_privacy: Option<Vec<String>>Contact privacy options that the domain supports.
yearly_price: Option<Money>Price to register or renew the domain for one year.