pub struct RetrieveGoogleDomainsForwardingConfigResponse {
pub domain_forwardings: Option<Vec<DomainForwarding>>,
pub email_forwardings: Option<Vec<EmailForwarding>>,
}Expand description
Response for the RetrieveGoogleDomainsForwardingConfig method.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
Fields
domain_forwardings: Option<Vec<DomainForwarding>>The list of domain forwarding configurations. A forwarding configuration might not work correctly if the required DNS records are not present in the domain’s authoritative DNS zone.
email_forwardings: Option<Vec<EmailForwarding>>The list of email forwarding configurations. A forwarding configuration might not work correctly if the required DNS records are not present in the domain’s authoritative DNS zone.