pub struct RetrieveImportableDomainsResponse {
pub domains: Option<Vec<Domain>>,
pub next_page_token: Option<String>,
}Expand description
Deprecated: For more information, see Cloud Domains feature deprecation. Response for the RetrieveImportableDomains method.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
Fields
domains: Option<Vec<Domain>>A list of domains that the calling user manages in Google Domains.
next_page_token: Option<String>When present, there are more results to retrieve. Set page_token to this value on a subsequent call to get the next page of results.