pub struct RetrieveRegisterParametersResponse {
pub register_parameters: Option<RegisterParameters>,
}Expand description
Response for the RetrieveRegisterParameters method.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
Fields
register_parameters: Option<RegisterParameters>Parameters to use when calling the RegisterDomain method.