pub struct TransferParameters {
pub current_registrar: Option<String>,
pub current_registrar_uri: Option<String>,
pub domain_name: Option<String>,
pub name_servers: Option<Vec<String>>,
pub supported_privacy: Option<Vec<String>>,
pub transfer_lock_state: Option<String>,
pub yearly_price: Option<Money>,
}Expand description
Deprecated: For more information, see Cloud Domains feature deprecation. Parameters required to transfer a domain from another registrar.
This type is not used in any activity, and only used as part of another schema.
Fields
current_registrar: Option<String>The registrar that currently manages the domain.
current_registrar_uri: Option<String>The URL of the registrar that currently manages the domain.
domain_name: Option<String>The domain name. Unicode domain names are expressed in Punycode format.
name_servers: Option<Vec<String>>The name servers that currently store the configuration of the domain.
supported_privacy: Option<Vec<String>>Contact privacy options that the domain supports.
transfer_lock_state: Option<String>Indicates whether the domain is protected by a transfer lock. For a transfer to succeed, this must show UNLOCKED. To unlock a domain, go to its current registrar.
yearly_price: Option<Money>Price to transfer or renew the domain for one year.