pub struct RegisterDomainRequest {
pub contact_notices: Option<Vec<String>>,
pub domain_notices: Option<Vec<String>>,
pub registration: Option<Registration>,
pub validate_only: Option<bool>,
pub yearly_price: Option<Money>,
}Expand description
Request for the RegisterDomain method.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
Fields
contact_notices: Option<Vec<String>>The list of contact notices that the caller acknowledges. The notices needed here depend on the values specified in registration.contact_settings.
domain_notices: Option<Vec<String>>The list of domain notices that you acknowledge. Call RetrieveRegisterParameters to see the notices that need acknowledgement.
registration: Option<Registration>Required. The complete Registration resource to be created.
validate_only: Option<bool>When true, only validation is performed, without actually registering the domain. Follows: https://cloud.google.com/apis/design/design_patterns#request_validation
yearly_price: Option<Money>Required. Yearly price to register or renew the domain. The value that should be put here can be obtained from RetrieveRegisterParameters or SearchDomains calls.